@@ -77,10 +77,10 @@ xfae_window_class_init (XfaeWindowClass *klass)
 
 
 static void
-run_hook_changed (GtkCellRenderer *render,
-                  const gchar     *path_str,
-                  const gchar     *new_text,
-                  gpointer         user_data)
+run_hook_changed (GtkCellRendererCombo *combo,
+                  char                 *path_str,
+                  GtkTreeIter          *combo_iter,
+                  gpointer              user_data)
 {
     GEnumClass   *klass;
     GEnumValue   *enum_struct;
@@ -89,13 +89,21 @@ run_hook_changed (GtkCellRenderer *render,
     GtkTreePath  *path = gtk_tree_path_new_from_string (path_str);
     GtkTreeIter   iter;
     GError       *error = NULL;
+    GtkTreeModel *combo_model;
+    gchar        *combo_str;
 
     if (gtk_tree_model_get_iter (model, &iter, path))
       {
+        g_object_get (combo, "model", &combo_model, NULL);
+        combo_str = gtk_tree_model_get_string_from_iter (combo_model, combo_iter);
         klass = g_type_class_ref (XFSM_TYPE_RUN_HOOK);
-        enum_struct = g_enum_get_value_by_nick (klass, new_text);
+        enum_struct = g_enum_get_value (klass, atoi (combo_str));
         g_type_class_unref (klass);
-        if (!xfae_model_set_run_hook (model, path, &iter, enum_struct->value, &error))
+        g_free (combo_str);
+        g_object_unref (combo_model);
+
+        if (enum_struct != NULL
+            && !xfae_model_set_run_hook (model, path, &iter, enum_struct->value, &error))
           {
             xfce_dialog_show_error (NULL, error, _("Failed to set run hook"));
             g_error_free (error);
@@ -191,7 +199,7 @@ xfae_window_init (XfaeWindow *window)
   renderer = gtk_cell_renderer_pixbuf_new ();
   gtk_tree_view_column_pack_start (column, renderer, FALSE);
   gtk_tree_view_column_set_attributes (column, renderer,
-                                       "pixbuf", XFAE_MODEL_COLUMN_ICON,
+                                       "gicon", XFAE_MODEL_COLUMN_ICON,
                                        NULL);
   renderer = gtk_cell_renderer_text_new ();
   g_object_set (renderer,
@@ -222,7 +230,7 @@ xfae_window_init (XfaeWindow *window)
                 "editable", TRUE,
                 "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
                 NULL);
-  g_signal_connect (renderer, "edited", G_CALLBACK (run_hook_changed), window->treeview);
+  g_signal_connect (renderer, "changed", G_CALLBACK (run_hook_changed), window->treeview);
 
   gtk_tree_view_column_pack_start (column, renderer, FALSE);
   gtk_tree_view_column_set_attributes (column, renderer,
@@ -238,7 +246,7 @@ xfae_window_init (XfaeWindow *window)
   gtk_style_context_add_class (gtk_widget_get_style_context (bbox), "inline-toolbar");
   gtk_widget_show (bbox);
 
-  button = gtk_button_new ();
+  button = gtk_button_new_with_label (_("Add"));
   img = gtk_image_new_from_icon_name ("list-add-symbolic", GTK_ICON_SIZE_BUTTON);
   gtk_button_set_image (GTK_BUTTON (button), img);
   gtk_widget_set_tooltip_text (GTK_WIDGET (button), _("Add application"));
@@ -247,7 +255,7 @@ xfae_window_init (XfaeWindow *window)
   gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
 
-  button = gtk_button_new ();
+  button = gtk_button_new_with_label (_("Remove"));
   img = gtk_image_new_from_icon_name ("list-remove-symbolic", GTK_ICON_SIZE_BUTTON);
   gtk_button_set_image (GTK_BUTTON (button), img);
   gtk_widget_set_tooltip_text (GTK_WIDGET (button), _("Remove application"));
@@ -260,7 +268,7 @@ xfae_window_init (XfaeWindow *window)
                     G_CALLBACK (xfae_window_selection_changed), button);
   xfae_window_selection_changed (window->selection, button);
 
-  button = gtk_button_new ();
+  button = gtk_button_new_with_label (_("Edit"));
   img = gtk_image_new_from_icon_name ("document-edit-symbolic", GTK_ICON_SIZE_BUTTON);
   gtk_button_set_image (GTK_BUTTON (button), img);
   gtk_widget_set_tooltip_text (GTK_WIDGET (button), _("Edit application"));
@@ -290,7 +298,7 @@ xfae_window_create_run_hooks_combo_model (void)
       {
         gtk_list_store_append (ls, &iter);
         enum_struct = g_enum_get_value (klass, i);
-        gtk_list_store_set (ls, &iter, 0, enum_struct->value_nick, -1);
+        gtk_list_store_set (ls, &iter, 0, _(enum_struct->value_nick), -1);
       }
     g_type_class_unref (klass);
     return GTK_TREE_MODEL (ls);
@@ -346,8 +354,7 @@ xfae_window_button_press_event (GtkWidget      *treeview,
           g_signal_connect_swapped (G_OBJECT (menu), "deactivate",
                                     G_CALLBACK (g_main_loop_quit), loop);
           gtk_grab_add (menu);
-          gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL,
-                          NULL, event->button, event->time);
+          gtk_menu_popup_at_pointer (GTK_MENU (menu), (GdkEvent *) event);
           g_main_loop_run (loop);
           g_main_loop_unref (loop);
           gtk_grab_remove (menu);
