@@ -36,7 +36,6 @@
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
 
-#include <libxfsm/xfsm-splash-engine.h>
 #include <libxfsm/xfsm-util.h>
 
 #include <xfce4-session/xfsm-chooser.h>
@@ -53,16 +52,6 @@ static void xfsm_chooser_realized      (GtkWidget         *widget,
                                         XfsmChooser       *chooser);
 
 
-enum
-{
-  PREVIEW_COLUMN,
-  NAME_COLUMN,
-  TITLE_COLUMN,
-  ATIME_COLUMN,
-  N_COLUMNS,
-};
-
-
 
 G_DEFINE_TYPE (XfsmChooser, xfsm_chooser, GTK_TYPE_DIALOG)
 
@@ -73,37 +62,35 @@ xfsm_chooser_set_sessions (XfsmChooser *chooser,
                            GList       *sessions,
                            const gchar *default_session)
 {
-  XfsmSessionInfo *session;
   GtkTreeModel    *model;
-  GtkTreeIter      iter;
-  gchar           *accessed;
-  gchar           *title;
-  GList           *lp;
 
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (chooser->tree));
-  gtk_list_store_clear (GTK_LIST_STORE (model));
 
-  for (lp = sessions; lp != NULL; lp = lp->next)
-    {
-      session = (XfsmSessionInfo *) lp->data;
+  settings_list_sessions_populate (GTK_TREE_MODEL (model), sessions);
+}
 
-      accessed = g_strdup_printf (_("Last accessed: %s"),
-                                  ctime (&session->atime));
-      title = g_strdup_printf ("<b><big>%s</big></b>\n"
-                               "<small><i>%s</i></small>",
-                               session->name, accessed);
 
-      gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-      gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-                          PREVIEW_COLUMN, session->preview,
-                          NAME_COLUMN, session->name,
-                          TITLE_COLUMN, title,
-                          ATIME_COLUMN, session->atime,
-                          -1);
+static void
+xfsm_chooser_new_session (GtkButton *button,
+                          XfsmChooser *chooser)
+{
+  gtk_dialog_response (GTK_DIALOG (chooser), XFSM_RESPONSE_NEW);
+}
 
-      g_free (accessed);
-      g_free (title);
-    }
+
+static void
+xfsm_chooser_logout (GtkButton *button,
+                     XfsmChooser *chooser)
+{
+  gtk_dialog_response (GTK_DIALOG (chooser), GTK_RESPONSE_CANCEL);
+}
+
+
+static void
+xfsm_chooser_start_session (GtkButton *button,
+                            XfsmChooser *chooser)
+{
+  gtk_dialog_response (GTK_DIALOG (chooser), XFSM_RESPONSE_LOAD);
 }
 
 
@@ -140,19 +127,29 @@ xfsm_chooser_class_init (XfsmChooserClass *klass)
 static void
 xfsm_chooser_init (XfsmChooser *chooser)
 {
-  GtkTreeSelection *selection;
-  GtkTreeViewColumn *column;
-  GtkCellRenderer *renderer;
-  GtkListStore *model;
   GtkWidget *button;
   GtkWidget *swin;
+  GtkWidget *vbox;
+  GtkWidget *hbox;
+  GtkWidget *label;
   GtkWidget *dbox;
+  gchar title[256];
 
   dbox = gtk_dialog_get_content_area(GTK_DIALOG (chooser));
 
   g_signal_connect_after (G_OBJECT (chooser), "realize",
                           G_CALLBACK (xfsm_chooser_realized), chooser);
 
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), 9);
+  gtk_box_pack_start (GTK_BOX (dbox), vbox, TRUE, TRUE, 0);
+  g_snprintf (title, 256, "<big><b>%s</b></big>",
+              _("Session Manager"));
+  label = gtk_label_new (title);
+  gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+  gtk_widget_set_margin_bottom (label, 12);
+  gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
+
   /* scrolled window */
   swin = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin),
@@ -160,58 +157,66 @@ xfsm_chooser_init (XfsmChooser *chooser)
                                   GTK_POLICY_AUTOMATIC);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (swin),
                                        GTK_SHADOW_ETCHED_IN);
-  gtk_box_pack_start (GTK_BOX (dbox), swin, TRUE, TRUE, 0);
-  gtk_widget_show (swin);
+  gtk_scrolled_window_set_min_content_height (GTK_SCROLLED_WINDOW (swin),
+                                              200);
+  gtk_box_pack_start (GTK_BOX (vbox), swin, TRUE, TRUE, 0);
 
   /* tree view */
-  model = gtk_list_store_new (N_COLUMNS,
-                              GDK_TYPE_PIXBUF,
-                              G_TYPE_STRING,
-                              G_TYPE_STRING,
-                              G_TYPE_INT);
-  chooser->tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
-  g_object_unref (G_OBJECT (model));
+  chooser->tree = gtk_tree_view_new ();
+  settings_list_sessions_treeview_init (GTK_TREE_VIEW (chooser->tree));
   gtk_widget_set_tooltip_text (chooser->tree,
                                _("Choose the session you want to restore. "
                                  "You can simply double-click the session "
                                  "name to restore it."));
-
-  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (chooser->tree), FALSE);
-  column = gtk_tree_view_column_new ();
-  renderer = gtk_cell_renderer_pixbuf_new ();
-  gtk_tree_view_column_pack_start (column, renderer, FALSE);
-  gtk_tree_view_column_set_attributes (column, renderer,
-                                       "pixbuf", PREVIEW_COLUMN,
-                                       NULL);
-  renderer = gtk_cell_renderer_text_new ();
-  gtk_tree_view_column_pack_start (column, renderer, TRUE);
-  gtk_tree_view_column_set_attributes (column, renderer,
-                                       "markup", TITLE_COLUMN,
-                                       NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (chooser->tree), column);
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (chooser->tree));
-  gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
   g_signal_connect (G_OBJECT (chooser->tree), "row-activated",
                     G_CALLBACK (xfsm_chooser_row_activated), chooser);
   gtk_container_add (GTK_CONTAINER (swin), chooser->tree);
   gtk_widget_set_size_request (chooser->tree, -1, 150);
-  gtk_widget_show (chooser->tree);
+
+  /* Session Treeview inline toolbar */
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
+  gtk_widget_set_margin_bottom (hbox, 12);
+  gtk_style_context_add_class (gtk_widget_get_style_context (hbox), "inline-toolbar");
+
+  /* "New" button */
+  button = gtk_button_new_from_icon_name ("list-add-symbolic", GTK_ICON_SIZE_BUTTON);
+  gtk_widget_set_tooltip_text (button, _("Create a new session."));
+  g_signal_connect (G_OBJECT (button), "clicked",
+                    G_CALLBACK (xfsm_chooser_new_session), chooser);
+  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+
+  /* "Delete" button */
+  button = gtk_button_new_from_icon_name ("list-remove-symbolic", GTK_ICON_SIZE_BUTTON);
+  gtk_widget_set_tooltip_text (button, _("Delete a saved session."));
+  g_signal_connect (G_OBJECT (button), "clicked",
+                    G_CALLBACK (settings_list_sessions_delete_session), GTK_TREE_VIEW (chooser->tree));
+  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+
+  /* Button box */
+  hbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_EDGE);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
 
   /* "Logout" button */
-  button = xfce_gtk_button_new_mixed ("application-exit", _("Log out"));
+  button = xfce_gtk_button_new_mixed ("application-exit", _("Log Out"));
   gtk_widget_set_tooltip_text (button,
                                _("Cancel the login attempt and return to "
                                  "the login screen."));
-  gtk_dialog_add_action_widget (GTK_DIALOG (chooser), button,
-                                GTK_RESPONSE_CANCEL);
-  gtk_widget_show (button);
+  g_signal_connect (G_OBJECT (button), "clicked",
+                    G_CALLBACK (xfsm_chooser_logout), chooser);
+  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
-  /* "New" button */
-  button = xfce_gtk_button_new_mixed ("document-new", _("New session"));
-  gtk_widget_set_tooltip_text (button, _("Create a new session."));
-  gtk_dialog_add_action_widget (GTK_DIALOG (chooser), button,
-                                XFSM_RESPONSE_NEW);
-  gtk_widget_show (button);
+  /* "Start" button */
+  button = xfce_gtk_button_new_mixed ("", _("Start"));
+  gtk_widget_set_tooltip_text (button, _("Start an existing session."));
+  gtk_style_context_add_class (gtk_widget_get_style_context (button), "suggested-action");
+  gtk_dialog_set_default_response (GTK_DIALOG (chooser), XFSM_RESPONSE_LOAD);
+  g_signal_connect (G_OBJECT (button), "clicked",
+                    G_CALLBACK (xfsm_chooser_start_session), chooser);
+  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+
+  gtk_widget_show_all (vbox);
 }
 
 
@@ -235,4 +240,3 @@ xfsm_chooser_realized (GtkWidget   *widget,
   gdk_window_set_cursor (gtk_widget_get_window(widget), cursor);
   g_object_unref (cursor);
 }
-
