@@ -28,8 +28,10 @@
 
 
 void xfsm_legacy_perform_session_save (void);
-void xfsm_legacy_store_session (XfceRc *rc);
-void xfsm_legacy_load_session (XfceRc *rc);
+void xfsm_legacy_store_session (GKeyFile *file,
+                                const gchar *group);
+void xfsm_legacy_load_session (GKeyFile *file,
+                               const gchar *group);
 void xfsm_legacy_init (void);
 void xfsm_legacy_startup (void);
 void xfsm_legacy_shutdown (void);
