@@ -248,8 +248,7 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
    **/
   if (!xfsm_shutdown_can_restart (dialog->shutdown, &can_restart, &error))
     {
-      g_printerr ("%s: Querying CanRestart failed, %s\n\n",
-                  PACKAGE_NAME, ERROR_MSG (error));
+      g_warning ("Querying CanRestart failed: %s", ERROR_MSG (error));
       g_clear_error (&error);
 
       can_restart = FALSE;
@@ -268,8 +267,7 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
    **/
   if (!xfsm_shutdown_can_shutdown (dialog->shutdown, &can_shutdown, &error))
     {
-      g_printerr ("%s: Querying CanShutdown failed. %s\n\n",
-                  PACKAGE_NAME, ERROR_MSG (error));
+      g_warning ("Querying CanShutdown failed: %s", ERROR_MSG (error));
       g_clear_error (&error);
 
       can_shutdown = FALSE;
@@ -312,8 +310,7 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
         }
       else
         {
-          g_printerr ("%s: Querying suspend failed: %s\n\n",
-                      PACKAGE_NAME, ERROR_MSG (error));
+          g_warning ("Querying suspend failed: %s", ERROR_MSG (error));
           g_clear_error (&error);
 
           /* don't try hibernate again */
@@ -346,8 +343,7 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
         }
       else
         {
-          g_printerr ("%s: Querying hibernate failed: %s\n\n",
-                      PACKAGE_NAME, ERROR_MSG (error));
+          g_warning ("Querying hibernate failed: %s", ERROR_MSG (error));
           g_clear_error (&error);
         }
     }
@@ -377,8 +373,7 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
         }
       else
         {
-          g_printerr ("%s: Querying hybrid-sleep failed: %s\n\n",
-                      PACKAGE_NAME, ERROR_MSG (error));
+          g_warning ("Querying hybrid-sleep failed: %s", ERROR_MSG (error));
           g_clear_error (&error);
         }
     }
@@ -408,8 +403,7 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
         }
       else
         {
-          g_printerr ("%s: Querying switch user failed: %s\n\n",
-                      PACKAGE_NAME, ERROR_MSG (error));
+          g_warning ("Querying switch user failed: %s", ERROR_MSG (error));
           g_clear_error (&error);
         }
     }
@@ -652,13 +646,13 @@ xfsm_logout_dialog_screenshot_save (GdkPixbuf   *screenshot,
       path = g_strconcat ("sessions/thumbs-", display_name, "/", session_name, ".png", NULL);
       filename = xfce_resource_save_location (XFCE_RESOURCE_CACHE, path, TRUE);
       g_free (display_name);
-      g_free (path);
 
       if (!filename)
         {
           g_warning ("Unable to save screenshot, "
                      "error calling xfce_resource_save_location with %s, "
                      "check your permissions", path);
+          g_free (path);
           return;
         }
 
@@ -668,6 +662,7 @@ xfsm_logout_dialog_screenshot_save (GdkPixbuf   *screenshot,
           g_error_free (error);
         }
 
+      g_free (path);
       g_free (filename);
       g_object_unref (G_OBJECT (scaled));
     }
@@ -811,7 +806,7 @@ xfsm_logout_dialog (const gchar      *session_name,
 
           if (grab_count++ >= 40)
             {
-              g_critical ("Failed to grab the keyboard for logout window");
+              g_warning ("Failed to grab the keyboard for logout window");
               break;
             }
 
