@@ -42,6 +42,9 @@ G_BEGIN_DECLS
 #define SAVE_TIMEOUT           (    60 * 1000)
 #define STARTUP_TIMEOUT        (     8 * 1000)
 #define RESTART_RESET_TIMEOUT  (5 * 60 * 1000)
+#define XFSM_CHOOSE_LOGOUT  0
+#define XFSM_CHOOSE_LOAD    1
+#define XFSM_CHOOSE_NEW     2
 
 typedef enum
 {
@@ -58,7 +61,6 @@ typedef enum
     XFSM_MANAGER_QUEUE_STARTING_PROPS,
     XFSM_MANAGER_QUEUE_RESTART_PROPS,
     XFSM_MANAGER_QUEUE_RUNNING_CLIENTS,
-    XFSM_MANAGER_QUEUE_FAILSAFE_CLIENTS,
 } XfsmManagerQueueType;
 
 typedef enum
@@ -154,6 +156,8 @@ GQueue *xfsm_manager_get_queue (XfsmManager         *manager,
 
 gboolean xfsm_manager_get_use_failsafe_mode (XfsmManager *manager);
 
+void xfsm_manager_increase_failsafe_pending_clients (XfsmManager *manager);
+
 gboolean xfsm_manager_get_compat_startup (XfsmManager          *manager,
                                           XfsmManagerCompatType type);
 
