@@ -88,21 +88,6 @@ static const struct
 };
 
 
-#ifndef HAVE_STRDUP
-static char*
-strdup (const char *s)
-{
-  char *t;
-
-  t = (char *) malloc (strlen (s) + 1);
-  if (t != NULL)
-    strcpy (t, s);
-
-  return t;
-}
-#endif
-
-
 static gchar*
 compose (gchar       *buffer,
          gsize        length,
@@ -122,20 +107,20 @@ strv_to_property (const gchar *name,
   SmProp *prop;
   gint    argc;
 
-  prop       = (SmProp *) malloc (sizeof (*prop));
-  prop->name = strdup (name);
-  prop->type = strdup (SmLISTofARRAY8);
+  prop       = g_new (SmProp, 1);
+  prop->name = g_strdup (name);
+  prop->type = g_strdup (SmLISTofARRAY8);
 
   for (argc = 0; argv[argc] != NULL; ++argc)
     ;
 
   prop->num_vals = argc;
-  prop->vals     = (SmPropValue *) malloc (argc * sizeof (SmPropValue));
+  prop->vals     = g_new (SmPropValue, argc);
 
   while (argc-- > 0)
     {
       prop->vals[argc].length = strlen (argv[argc]) + 1;
-      prop->vals[argc].value  = strdup (argv[argc]);
+      prop->vals[argc].value  = g_strdup (argv[argc]);
     }
 
   return prop;
@@ -148,13 +133,13 @@ str_to_property (const gchar *name,
 {
   SmProp *prop;
 
-  prop                 = (SmProp *) malloc (sizeof (*prop));
-  prop->name           = strdup (name);
-  prop->type           = strdup (SmARRAY8);
+  prop                 = g_new (SmProp, 1);
+  prop->name           = g_strdup (name);
+  prop->type           = g_strdup (SmARRAY8);
   prop->num_vals       = 1;
-  prop->vals           = (SmPropValue *) malloc (sizeof (SmPropValue));
+  prop->vals           = g_new (SmPropValue, 1);
   prop->vals[0].length = strlen (value) + 1;
-  prop->vals[0].value  = strdup (value);
+  prop->vals[0].value  = g_strdup (value);
 
   return prop;
 }
@@ -167,14 +152,14 @@ int_to_property (const gchar *name,
   SmProp *prop;
   gint8  *p;
 
-  p    = (gint8 *) malloc (1);
+  p    = g_new (gint8, 1);
   p[0] = (gint8) value;
 
-  prop                 = (SmProp *) malloc (sizeof (*prop));
-  prop->name           = strdup (name);
-  prop->type           = strdup (SmCARD8);
+  prop                 = g_new (SmProp, 1);
+  prop->name           = g_strdup (name);
+  prop->type           = g_strdup (SmCARD8);
   prop->num_vals       = 1;
-  prop->vals           = (SmPropValue *) malloc (sizeof (SmPropValue));
+  prop->vals           = g_new (SmPropValue, 1);
   prop->vals[0].length = 1;
   prop->vals[0].value  = p;
 
@@ -235,7 +220,7 @@ xfsm_properties_extract (XfsmProperties *properties,
   g_return_if_fail (num_props != NULL);
   g_return_if_fail (props != NULL);
 
-  *props = pp = (SmProp **) malloc (sizeof (SmProp *) * g_tree_nnodes (properties->sm_properties));
+  *props = pp = g_new (SmProp *, g_tree_nnodes (properties->sm_properties));
 
   g_tree_foreach (properties->sm_properties,
                   xfsm_properties_extract_foreach,
@@ -246,8 +231,9 @@ xfsm_properties_extract (XfsmProperties *properties,
 
 
 XfsmProperties *
-xfsm_properties_load (XfceRc      *rc,
-                      const gchar *prefix)
+xfsm_properties_load (GKeyFile    *file,
+                      const gchar *prefix,
+                      const gchar *group)
 {
 #define ENTRY(name) (compose(buffer, 256, prefix, (name)))
 
@@ -255,25 +241,28 @@ xfsm_properties_load (XfceRc      *rc,
   const gchar    *client_id;
   const gchar    *hostname;
   GValue         *value;
+  GError         *error = NULL;
   const gchar    *value_str;
   gchar         **value_strv;
   gint            value_int;
   gchar           buffer[256];
   gint            i;
 
-  client_id = xfce_rc_read_entry (rc, ENTRY ("ClientId"), NULL);
+  client_id = g_key_file_get_string (file, group, ENTRY ("ClientId"), &error);
   if (client_id == NULL)
     {
       g_warning ("Session data broken, stored client is missing a client id. "
-                 "Skipping client.");
+                 "Skipping client: %s", error->message);
+      g_error_free (error);
       return NULL;
     }
 
-  hostname = xfce_rc_read_entry (rc, ENTRY ("Hostname"), NULL);
+  hostname = g_key_file_get_string (file, group, ENTRY ("Hostname"), &error);
   if (hostname == NULL)
     {
       g_warning ("Session data broken, stored client is missing a hostname. "
-                 "Skipping client.");
+                 "Skipping client: %s", error->message);
+      g_error_free (error);
       return NULL;
     }
 
@@ -283,9 +272,17 @@ xfsm_properties_load (XfceRc      *rc,
 
   for (i = 0; strv_properties[i].name; ++i)
     {
-      value_strv = xfce_rc_read_list_entry (rc, ENTRY (strv_properties[i].name), NULL);
+      value_strv = g_key_file_get_string_list (file, group, ENTRY (strv_properties[i].name), NULL, NULL);
       if (value_strv)
         {
+          /* unescape delimiter in list entries */
+          for (gchar **str = value_strv; *str != NULL; str++)
+            {
+              gchar *unesc_str = xfce_str_replace (*str, "\\" SESSION_FILE_DELIMITER, SESSION_FILE_DELIMITER);
+              g_free (*str);
+              *str = unesc_str;
+            }
+
           xfsm_verbose ("-> Set strv (%s)\n", strv_properties[i].xsmp_name);
           /* don't use _set_strv() to avoid a realloc of the whole strv */
           value = xfsm_g_value_new (G_TYPE_STRV);
@@ -298,15 +295,19 @@ xfsm_properties_load (XfceRc      *rc,
 
   for (i = 0; str_properties[i].name; ++i)
     {
-      value_str = xfce_rc_read_entry (rc, ENTRY (str_properties[i].name), NULL);
+      value_str = g_key_file_get_string (file, group, ENTRY (str_properties[i].name), NULL);
       if (value_str)
         xfsm_properties_set_string (properties, str_properties[i].xsmp_name, value_str);
     }
 
   for (i = 0; uchar_properties[i].name; ++i)
     {
-      value_int = xfce_rc_read_int_entry (rc, ENTRY (uchar_properties[i].name),
-                                          uchar_properties[i].default_value);
+      value_int = g_key_file_get_integer (file, group, ENTRY (uchar_properties[i].name), &error);
+      if (error != NULL)
+        {
+          value_int = uchar_properties[i].default_value;
+          g_clear_error (&error);
+        }
       xfsm_properties_set_uchar (properties, uchar_properties[i].xsmp_name, value_int);
     }
 
@@ -324,8 +325,9 @@ xfsm_properties_load (XfceRc      *rc,
 
 void
 xfsm_properties_store (XfsmProperties *properties,
-                       XfceRc         *rc,
-                       const gchar    *prefix)
+                       GKeyFile       *file,
+                       const gchar    *prefix,
+                       const gchar    *group)
 {
 #define ENTRY(name) (compose(buffer, 256, prefix, (name)))
 
@@ -333,16 +335,24 @@ xfsm_properties_store (XfsmProperties *properties,
   gint    i;
   gchar   buffer[256];
 
-  xfce_rc_write_entry (rc, ENTRY ("ClientId"), properties->client_id);
-  xfce_rc_write_entry (rc, ENTRY ("Hostname"), properties->hostname);
+  g_key_file_set_string (file, group, ENTRY ("ClientId"), properties->client_id);
+  g_key_file_set_string (file, group, ENTRY ("Hostname"), properties->hostname);
 
   for (i = 0; strv_properties[i].name; ++i)
     {
       value = g_tree_lookup (properties->sm_properties, strv_properties[i].xsmp_name);
       if (value)
         {
-          xfce_rc_write_list_entry (rc, ENTRY (strv_properties[i].name),
-                                    g_value_get_boxed (value), NULL);
+          /* escape delimiter in list entries */
+          const gchar * const *strv = g_value_get_boxed (value);
+          guint len = g_strv_length ((gchar **) strv);
+          gchar **esc_strv = g_new0 (gchar *, len + 1);
+          for (guint j = 0; j < len; j++)
+            esc_strv[j] = xfce_str_replace (strv[j], SESSION_FILE_DELIMITER, "\\" SESSION_FILE_DELIMITER);
+
+          g_key_file_set_string_list (file, group, ENTRY (strv_properties[i].name),
+                                      (const gchar * const *) esc_strv, len);
+          g_strfreev (esc_strv);
         }
     }
 
@@ -351,8 +361,8 @@ xfsm_properties_store (XfsmProperties *properties,
       value = g_tree_lookup (properties->sm_properties, str_properties[i].xsmp_name);
       if (value)
         {
-          xfce_rc_write_entry (rc, ENTRY (str_properties[i].name),
-                               g_value_get_string (value));
+          g_key_file_set_string (file, group, ENTRY (str_properties[i].name),
+                                 g_value_get_string (value));
         }
     }
 
@@ -361,8 +371,8 @@ xfsm_properties_store (XfsmProperties *properties,
       value = g_tree_lookup (properties->sm_properties, uchar_properties[i].xsmp_name);
       if (value)
         {
-          xfce_rc_write_int_entry (rc, ENTRY (uchar_properties[i].name),
-                                   g_value_get_uchar (value));
+          g_key_file_set_integer (file, group, ENTRY (uchar_properties[i].name),
+                                  g_value_get_uchar (value));
         }
     }
 
